#
# spec file for package ghc-doctemplates
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name doctemplates
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.11
Release:        1.34
Summary:        Pandoc-style document templates
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-aeson-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-doclayout-devel
BuildRequires:  ghc-doclayout-prof
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-filepath-prof
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-mtl-prof
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-parsec-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-safe-devel
BuildRequires:  ghc-safe-prof
BuildRequires:  ghc-scientific-devel
BuildRequires:  ghc-scientific-prof
BuildRequires:  ghc-text-conversions-devel
BuildRequires:  ghc-text-conversions-prof
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-vector-devel
BuildRequires:  ghc-vector-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-Glob-devel
BuildRequires:  ghc-Glob-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-golden-devel
BuildRequires:  ghc-tasty-golden-prof
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-hunit-prof
BuildRequires:  ghc-tasty-prof
BuildRequires:  ghc-temporary-devel
BuildRequires:  ghc-temporary-prof
%endif

%description
This is the text templating system used by pandoc. It supports variable
interpolation, iteration, tests for non-blank values, pipes, and partials.
Templates are rendered to doclayout Docs, and variable values may come from a
variety of different sources, including aeson Values.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE
%dir %{_datadir}/%{pkg_name}-%{version}
%{_datadir}/%{pkg_name}-%{version}/README.md
%{_datadir}/%{pkg_name}-%{version}/changelog.md

%files devel -f %{name}-devel.files

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Mon Nov 21 2022 Peter Simons <psimons@suse.com>
- Update doctemplates to version 0.11.
  Upstream has not updated the file "changelog.md" since the last
  release.
* Sat Aug 13 2022 Peter Simons <psimons@suse.com>
- Update doctemplates to version 0.10.0.2 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Apr  4 2022 Peter Simons <psimons@suse.com>
- Update doctemplates to version 0.10.0.2.
  [#]# 0.10.0.2
  * Use doclayout 0.4.
* Tue Oct 12 2021 psimons@suse.com
- Update doctemplates to version 0.10.0.1.
  [#]# 0.10.0.1
  * Don't rely on aeson Object being implemented as a HashMap.
    This change is needed for doctemplates to compile against aeson 2.0.0.0.
* Mon Jul 19 2021 psimons@suse.com
- Update doctemplates to version 0.10.
  [#]# 0.10
  * Change rendering and conditional behavior with booleans.
    Previously, `$if(foo)$` evaluated to false iff `foo`
    would render as the empty string. This forced us to render
    a boolean False value as an empty string, rather than `false`.
    And this has caused various problems with templates
    (#16, jgm/pandoc#7402).  Now, boolean False values render as
    `false` -- just as True values render as `true`.  And conditionals
    are now sensitive to booleans, so `$if(foo)$` evaluates to false
    when `foo` is a boolean False value, even though it would render
    as the nonempty string `false`.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Thu Dec 17 2020 psimons@suse.com
- Update doctemplates to version 0.9.
  [#]# 0.9
  * Add BoolVal constructor to Val.  This gives a smoother
    interface with JSON and YAML.  [API change]
  * Remove overlapping instances by generalizing
    `ToContext String String` and `FromContext String String`
    to `TemplateTarget [a] => ToContext [a] [a]` and
    `TemplateTarget [a] => FromContext [a] [a]`.
    Remove the instance `ToContext String (Doc String)`.
    Remove redundant constraints.  (#9, favonia) [API change]
* Tue Dec  1 2020 psimons@suse.com
- Update doctemplates to version 0.8.3.
  [#]# 0.8.3
  * Properly handle nested loops (#15).  Previously "it" was
    always used for the variable in a loop, and in a nested loop
    there was no way to distinguish the value of the inner
    iteration from the value of the outer one.  Now we assign
    the iterated value to both "it" and to the original variable
    name (e.g. "foo.bar").  This probably has a small negative
    performance impact.  Note that this change also affects
    the output of the template parser:  original variable
    names are now retained instead of being replaced by "it".
  * Remove duplicate IsString constraint (#14, Mario Lang).
  * Update haddocks from README (#10).
  * Minor code clean-ups (#7, favonia).
  * Add hsyaml >= 0.2 constraint (#6).
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Wed May  6 2020 psimons@suse.com
- Update doctemplates to version 0.8.2.
  [#]# 0.8.2
  * Add filters: first, rest, last, allbutlast.
  * New constructors for Filter: FirstItem, LastItem, Rest, AllButLast
    [API change].
* Thu Feb 27 2020 psimons@suse.com
- Update doctemplates to version 0.8.1.
  [#]# 0.8.1
  * Depend on doclayout 0.3, which adds an additional method
    on the HasChars class.  This fixes some stack overflows
    in rendering very long lines.
* Mon Dec 23 2019 psimons@suse.com
- Update doctemplates to version 0.8.
  Upstream added a new change log file in this release. With no
  previous version to compare against, the automatic updater cannot
  reliable determine the relevante entries for this release.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update doctemplates to version 0.2.2.1.
  Upstream does not provide a changelog.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Sun Feb 12 2017 psimons@suse.com
- Update to version 0.1.0.2 with cabal2obs.
